@@ -1,4 +1,4 @@
 #[derive(Protocol, Debug, Clone, PartialEq)]
 pub struct RandomMap {
-    random_maps_ptr: i32,
+    pub random_maps_ptr: i32,
 }
